@@ -7,11 +7,11 @@ import muffin
 import peewee as pw
 from aiopeewee import db_url, DatabaseAsync
 from muffin.typing import Receive, Send
-from muffin.plugin import BasePlugin
+from muffin.plugins import BasePlugin
 from peewee_migrate import Router
 
 
-__version__ = "1.7.9"
+__version__ = "1.7.10"
 __project__ = "muffin-peewee"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
